@@ -22,6 +22,7 @@ import org.apache.eventmesh.common.file.FileChangeListener;
 import org.apache.eventmesh.common.file.WatchFileManager;
 
 import org.apache.commons.lang3.StringUtils;
+import org.apache.logging.log4j.util.Strings;
 
 import java.io.BufferedReader;
 import java.io.File;
@@ -63,13 +64,14 @@ public class ConfigurationWrapper {
     };
 
     public ConfigurationWrapper(String directoryPath, String fileName, boolean reload) {
+        Preconditions.checkArgument(Strings.isNotEmpty(directoryPath), "please configure environment variable 'confPath'");
         this.directoryPath = directoryPath
-                .replace('/', File.separator.charAt(0))
-                .replace('\\', File.separator.charAt(0));
+            .replace('/', File.separator.charAt(0))
+            .replace('\\', File.separator.charAt(0));
         this.fileName = fileName;
         this.file = (directoryPath + File.separator + fileName)
-                .replace('/', File.separator.charAt(0))
-                .replace('\\', File.separator.charAt(0));
+            .replace('/', File.separator.charAt(0))
+            .replace('\\', File.separator.charAt(0));
         this.reload = reload;
         init();
     }
@@ -104,7 +106,7 @@ public class ConfigurationWrapper {
             return defaultValue;
         }
         Preconditions.checkState(StringUtils.isNumeric(configValue),
-                String.format("key:%s, value:%s error", configKey, configValue));
+            String.format("key:%s, value:%s error", configKey, configValue));
         return Integer.parseInt(configValue);
     }
 
@@ -138,4 +140,8 @@ public class ConfigurationWrapper {
         return (T) objectMapper.convertValue(getPropertiesByConfig(prefix, removePrefix), clazz);
     }
 
+    public Properties getProperties() {
+        return this.properties;
+    }
+
 }
\ No newline at end of file
