@@ -55,7 +55,7 @@ public class SubscribeResponseBody extends Body {
         this.resTime = resTime;
     }
 
-    public static SubscribeResponseBody buildBody(Integer retCode, String retMsg) throws Exception {
+    public static SubscribeResponseBody buildBody(Integer retCode, String retMsg) {
         SubscribeResponseBody regResponseBody = new SubscribeResponseBody();
         regResponseBody.setRetMsg(retMsg);
         regResponseBody.setResTime(System.currentTimeMillis());
@@ -67,9 +67,9 @@ public class SubscribeResponseBody extends Body {
     public String toString() {
         StringBuilder sb = new StringBuilder();
         sb.append("regResponseBody={")
-                .append("retCode=").append(retCode).append(",")
-                .append("retMsg=").append(retMsg).append(",")
-                .append("resTime=").append(DateFormatUtils.format(resTime, Constants.DATE_FORMAT)).append("}");
+            .append("retCode=").append(retCode).append(",")
+            .append("retMsg=").append(retMsg).append(",")
+            .append("resTime=").append(DateFormatUtils.format(resTime, Constants.DATE_FORMAT)).append("}");
         return sb.toString();
     }
 
