@@ -18,7 +18,6 @@
 package org.apache.eventmesh.connector.rocketmq.consumer;
 
 import org.apache.eventmesh.api.AbstractContext;
-import org.apache.eventmesh.api.AsyncConsumeContext;
 import org.apache.eventmesh.api.EventListener;
 import org.apache.eventmesh.api.EventMeshAction;
 import org.apache.eventmesh.api.EventMeshAsyncConsumeContext;
@@ -47,9 +46,7 @@ import org.apache.rocketmq.remoting.protocol.LanguageCode;
 
 import java.util.ArrayList;
 import java.util.List;
-import java.util.Map;
 import java.util.Properties;
-import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.atomic.AtomicBoolean;
 
 import io.cloudevents.CloudEvent;
@@ -75,7 +72,7 @@ public class PushConsumerImpl {
         String consumerGroup = clientConfig.getConsumerId();
         if (null == consumerGroup || consumerGroup.isEmpty()) {
             throw new ConnectorRuntimeException(
-                    "Consumer Group is necessary for RocketMQ, please set it.");
+                "Consumer Group is necessary for RocketMQ, please set it.");
         }
         this.rocketmqPushConsumer.setConsumerGroup(consumerGroup);
         this.rocketmqPushConsumer.setMaxReconsumeTimes(clientConfig.getRmqMaxRedeliveryTimes());
@@ -83,7 +80,7 @@ public class PushConsumerImpl {
         this.rocketmqPushConsumer.setConsumeThreadMax(clientConfig.getRmqMaxConsumeThreadNums());
         this.rocketmqPushConsumer.setConsumeThreadMin(clientConfig.getRmqMinConsumeThreadNums());
         this.rocketmqPushConsumer.setMessageModel(
-                MessageModel.valueOf(clientConfig.getMessageModel()));
+            MessageModel.valueOf(clientConfig.getMessageModel()));
 
         String consumerId = OMSUtil.buildInstanceName();
         //this.rocketmqPushConsumer.setInstanceName(consumerId);
@@ -142,7 +139,6 @@ public class PushConsumerImpl {
         }
     }
 
-
     public void unsubscribe(String topic) {
         try {
             this.rocketmqPushConsumer.unsubscribe(topic);
@@ -153,14 +149,16 @@ public class PushConsumerImpl {
 
     public void updateOffset(List<CloudEvent> cloudEvents, AbstractContext context) {
         ConsumeMessageService consumeMessageService = rocketmqPushConsumer
-                .getDefaultMQPushConsumerImpl().getConsumeMessageService();
+            .getDefaultMQPushConsumerImpl().getConsumeMessageService();
         List<MessageExt> msgExtList = new ArrayList<>(cloudEvents.size());
         for (CloudEvent msg : cloudEvents) {
-            msgExtList.add(CloudEventUtils.msgConvertExt(
+            if (msg != null) {
+                msgExtList.add(CloudEventUtils.msgConvertExt(
                     RocketMQMessageFactory.createWriter(msg.getSubject()).writeBinary(msg)));
+            }
         }
         ((ConsumeMessageConcurrentlyService) consumeMessageService)
-                .updateOffset(msgExtList, (EventMeshConsumeConcurrentlyContext) context);
+            .updateOffset(msgExtList, (EventMeshConsumeConcurrentlyContext) context);
     }
 
 
@@ -174,13 +172,13 @@ public class PushConsumerImpl {
             }
 
             msg.putUserProperty(Constants.PROPERTY_MESSAGE_BORN_TIMESTAMP,
-                    String.valueOf(msg.getBornTimestamp()));
+                String.valueOf(msg.getBornTimestamp()));
             msg.putUserProperty(Constants.PROPERTY_MESSAGE_STORE_TIMESTAMP,
-                    String.valueOf(msg.getStoreTimestamp()));
+                String.valueOf(msg.getStoreTimestamp()));
 
             //for rr request/reply
             CloudEvent cloudEvent =
-                    RocketMQMessageFactory.createReader(CloudEventUtils.msgConvert(msg)).toEvent();
+                RocketMQMessageFactory.createReader(CloudEventUtils.msgConvert(msg)).toEvent();
 
             CloudEventBuilder cloudEventBuilder = null;
             for (String sysPropKey : MessageConst.STRING_HASH_SET) {
@@ -196,27 +194,27 @@ public class PushConsumerImpl {
 
             if (eventListener == null) {
                 throw new ConnectorRuntimeException(String.format("The topic/queue %s isn't attached to this consumer",
-                        msg.getTopic()));
+                    msg.getTopic()));
             }
 
             final Properties contextProperties = new Properties();
             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                    EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
+                EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
             EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext = new EventMeshAsyncConsumeContext() {
                 @Override
                 public void commit(EventMeshAction action) {
                     switch (action) {
                         case CommitMessage:
                             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                                    EventMeshConsumeConcurrentlyStatus.CONSUME_SUCCESS.name());
+                                EventMeshConsumeConcurrentlyStatus.CONSUME_SUCCESS.name());
                             break;
                         case ReconsumeLater:
                             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                                    EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
+                                EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
                             break;
                         case ManualAck:
                             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                                    EventMeshConsumeConcurrentlyStatus.CONSUME_FINISH.name());
+                                EventMeshConsumeConcurrentlyStatus.CONSUME_FINISH.name());
                             break;
                         default:
                             break;
@@ -229,7 +227,7 @@ public class PushConsumerImpl {
             eventListener.consume(cloudEvent, eventMeshAsyncConsumeContext);
 
             return EventMeshConsumeConcurrentlyStatus.valueOf(
-                    contextProperties.getProperty(NonStandardKeys.MESSAGE_CONSUME_STATUS));
+                contextProperties.getProperty(NonStandardKeys.MESSAGE_CONSUME_STATUS));
         }
 
 
@@ -245,12 +243,12 @@ public class PushConsumerImpl {
             }
 
             msg.putUserProperty(Constants.PROPERTY_MESSAGE_BORN_TIMESTAMP,
-                    String.valueOf(msg.getBornTimestamp()));
+                String.valueOf(msg.getBornTimestamp()));
             msg.putUserProperty(EventMeshConstants.STORE_TIMESTAMP,
-                    String.valueOf(msg.getStoreTimestamp()));
+                String.valueOf(msg.getStoreTimestamp()));
 
             CloudEvent cloudEvent =
-                    RocketMQMessageFactory.createReader(CloudEventUtils.msgConvert(msg)).toEvent();
+                RocketMQMessageFactory.createReader(CloudEventUtils.msgConvert(msg)).toEvent();
 
             CloudEventBuilder cloudEventBuilder = null;
 
@@ -267,13 +265,13 @@ public class PushConsumerImpl {
 
             if (eventListener == null) {
                 throw new ConnectorRuntimeException(String.format("The topic/queue %s isn't attached to this consumer",
-                        msg.getTopic()));
+                    msg.getTopic()));
             }
 
             final Properties contextProperties = new Properties();
 
             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                    EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
+                EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
 
             EventMeshAsyncConsumeContext eventMeshAsyncConsumeContext = new EventMeshAsyncConsumeContext() {
                 @Override
@@ -281,15 +279,15 @@ public class PushConsumerImpl {
                     switch (action) {
                         case CommitMessage:
                             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                                    EventMeshConsumeConcurrentlyStatus.CONSUME_SUCCESS.name());
+                                EventMeshConsumeConcurrentlyStatus.CONSUME_SUCCESS.name());
                             break;
                         case ReconsumeLater:
                             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                                    EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
+                                EventMeshConsumeConcurrentlyStatus.RECONSUME_LATER.name());
                             break;
                         case ManualAck:
                             contextProperties.put(NonStandardKeys.MESSAGE_CONSUME_STATUS,
-                                    EventMeshConsumeConcurrentlyStatus.CONSUME_FINISH.name());
+                                EventMeshConsumeConcurrentlyStatus.CONSUME_FINISH.name());
                             break;
                         default:
                             break;
@@ -302,7 +300,7 @@ public class PushConsumerImpl {
             eventListener.consume(cloudEvent, eventMeshAsyncConsumeContext);
 
             return EventMeshConsumeConcurrentlyStatus.valueOf(
-                    contextProperties.getProperty(NonStandardKeys.MESSAGE_CONSUME_STATUS));
+                contextProperties.getProperty(NonStandardKeys.MESSAGE_CONSUME_STATUS));
         }
     }
 
