@@ -444,7 +444,7 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
             ConsumeReturnType returnType = ConsumeReturnType.SUCCESS;
             try {
                 ConsumeMessageConcurrentlyService.this.resetRetryTopic(msgs);
-                if (msgs != null && !msgs.isEmpty()) {
+                if (!msgs.isEmpty()) {
                     for (MessageExt msg : msgs) {
                         MessageAccessor.setConsumeStartTimeStamp(msg, String.valueOf(System.currentTimeMillis()));
                     }
@@ -504,4 +504,4 @@ public class ConsumeMessageConcurrentlyService implements ConsumeMessageService
         }
 
     }
-}
\ No newline at end of file
+}
