@@ -22,6 +22,7 @@ import static org.assertj.core.api.Fail.failBecauseExceptionWasNotThrown;
 import static org.mockito.ArgumentMatchers.any;
 
 import org.apache.eventmesh.api.exception.ConnectorRuntimeException;
+import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.connector.rocketmq.producer.AbstractProducer;
 import org.apache.eventmesh.connector.rocketmq.producer.ProducerImpl;
 
@@ -98,7 +99,7 @@ public class ProducerImplTest {
                 .withSource(URI.create("https://github.com/cloudevents/*****"))
                 .withType("producer.example")
                 .withSubject("HELLO_TOPIC")
-                .withData("hello world".getBytes())
+                .withData("hello world".getBytes(Constants.DEFAULT_CHARSET))
                 .build();
         org.apache.eventmesh.api.SendResult result =
                 producer.send(cloudEvent);
