@@ -19,7 +19,6 @@ package org.apache.eventmesh.connector.standalone.producer;
 
 import org.apache.eventmesh.api.RequestReplyCallback;
 import org.apache.eventmesh.api.SendCallback;
-import org.apache.eventmesh.api.SendResult;
 import org.apache.eventmesh.api.producer.Producer;
 
 import java.util.Properties;
@@ -58,11 +57,6 @@ public class StandaloneProducerAdaptor implements Producer {
         standaloneProducer = new StandaloneProducer(properties);
     }
 
-    @Override
-    public SendResult publish(CloudEvent cloudEvent) {
-        return standaloneProducer.publish(cloudEvent);
-    }
-
     @Override
     public void publish(CloudEvent cloudEvent, SendCallback sendCallback) throws Exception {
         standaloneProducer.publish(cloudEvent, sendCallback);
@@ -73,11 +67,6 @@ public class StandaloneProducerAdaptor implements Producer {
         standaloneProducer.sendOneway(cloudEvent);
     }
 
-    @Override
-    public void sendAsync(CloudEvent cloudEvent, SendCallback sendCallback) {
-        standaloneProducer.sendAsync(cloudEvent, sendCallback);
-    }
-
     @Override
     public void request(CloudEvent cloudEvent, RequestReplyCallback rrCallback, long timeout) throws Exception {
         standaloneProducer.request(cloudEvent, rrCallback, timeout);
