@@ -19,11 +19,14 @@
 
 package org.apache.eventmesh.runtime.boot;
 
+import org.apache.eventmesh.runtime.configuration.EventMeshHTTPConfiguration;
 import org.apache.eventmesh.runtime.constants.EventMeshConstants;
 
 import org.apache.commons.lang3.StringUtils;
 
 import java.io.File;
+import java.io.IOException;
+import java.io.InputStream;
 import java.nio.file.Files;
 import java.nio.file.Paths;
 import java.nio.file.StandardOpenOption;
@@ -45,29 +48,39 @@ public class SSLContextFactory {
     private static String pass;
 
 
-    public static SSLContext getSslContext() {
+    public static SSLContext getSslContext(EventMeshHTTPConfiguration eventMeshHttpConfiguration) {
         SSLContext sslContext;
+        InputStream inputStream = null;
         try {
-            protocol = System.getProperty("ssl.server.protocol", "TLSv1.1");
+            protocol = eventMeshHttpConfiguration.eventMeshServerSSLProtocol;
 
-            fileName = System.getProperty("ssl.server.cer", "sChat2.jks");
+            fileName = eventMeshHttpConfiguration.eventMeshServerSSLCer;
 
             char[] filePass = null;
-            pass = System.getProperty("ssl.server.pass", "sNetty");
+            pass = eventMeshHttpConfiguration.eventMeshServerSSLPass;
             if (StringUtils.isNotBlank(pass)) {
                 filePass = pass.toCharArray();
             }
             sslContext = SSLContext.getInstance(protocol);
             KeyStore keyStore = KeyStore.getInstance("JKS");
-            keyStore.load(Files.newInputStream(Paths.get(EventMeshConstants.EVENTMESH_CONF_HOME
-                    + File.separator
-                    + fileName), StandardOpenOption.READ), filePass);
+            inputStream = Files.newInputStream(Paths.get(EventMeshConstants.EVENTMESH_CONF_HOME
+                + File.separator
+                + fileName), StandardOpenOption.READ);
+            keyStore.load(inputStream, filePass);
             KeyManagerFactory kmf = KeyManagerFactory.getInstance(KeyManagerFactory.getDefaultAlgorithm());
             kmf.init(keyStore, filePass);
             sslContext.init(kmf.getKeyManagers(), null, null);
         } catch (Exception e) {
             httpLogger.warn("sslContext init failed", e);
             sslContext = null;
+        } finally {
+            if (inputStream != null) {
+                try {
+                    inputStream.close();
+                } catch (IOException e) {
+                    httpLogger.warn("IOException found", e);
+                }
+            }
         }
         return sslContext;
     }
