@@ -17,6 +17,7 @@
 
 package org.apache.eventmesh.runtime.core.protocol.http.processor;
 
+import org.apache.eventmesh.common.Constants;
 import org.apache.eventmesh.common.protocol.SubscriptionItem;
 import org.apache.eventmesh.common.protocol.http.HttpEventWrapper;
 import org.apache.eventmesh.common.protocol.http.common.EventMeshRetCode;
@@ -46,6 +47,7 @@ import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
+import java.util.Set;
 
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -76,8 +78,6 @@ public class LocalSubscribeEventProcessor extends AbstractEventProcessor impleme
 
         HttpEventWrapper requestWrapper = asyncContext.getRequest();
 
-        HttpEventWrapper responseWrapper;
-
         httpLogger.info("uri={}|{}|client2eventMesh|from={}|to={}", requestWrapper.getRequestURI(),
             EventMeshConstants.PROTOCOL_HTTP, RemotingHelper.parseChannelRemoteAddr(ctx.channel()), IPUtils.getLocalAddress()
         );
@@ -119,8 +119,8 @@ public class LocalSubscribeEventProcessor extends AbstractEventProcessor impleme
         //validate body
         byte[] requestBody = requestWrapper.getBody();
 
-        Map<String, Object> requestBodyMap = JsonUtils.deserialize(new String(requestBody), new TypeReference<HashMap<String, Object>>() {
-        });
+        Map<String, Object> requestBodyMap = JsonUtils.deserialize(new String(requestBody, Constants.DEFAULT_CHARSET),
+            new TypeReference<HashMap<String, Object>>() {});
 
         if (requestBodyMap.get("url") == null || requestBodyMap.get("topic") == null || requestBodyMap.get("consumerGroup") == null) {
             handlerSpecific.sendErrorResponse(EventMeshRetCode.EVENTMESH_PROTOCOL_BODY_ERR, responseHeaderMap,
@@ -234,20 +234,23 @@ public class LocalSubscribeEventProcessor extends AbstractEventProcessor impleme
                         newTopicConf.setIdcUrls(idcUrls);
                         map.put(subTopic.getTopic(), newTopicConf);
                     }
-                    for (String key : map.keySet()) {
-                        if (StringUtils.equals(subTopic.getTopic(), key)) {
-                            ConsumerGroupTopicConf latestTopicConf = new ConsumerGroupTopicConf();
-                            latestTopicConf.setConsumerGroup(consumerGroup);
-                            latestTopicConf.setTopic(subTopic.getTopic());
-                            latestTopicConf.setSubscriptionItem(subTopic);
-                            latestTopicConf.setUrls(new HashSet<>(Arrays.asList(url)));
-
-                            ConsumerGroupTopicConf currentTopicConf = map.get(key);
-                            latestTopicConf.getUrls().addAll(currentTopicConf.getUrls());
-                            latestTopicConf.setIdcUrls(idcUrls);
-
-                            map.put(key, latestTopicConf);
+                    Set<Map.Entry<String, ConsumerGroupTopicConf>> entrySet = map.entrySet();
+                    for (Map.Entry<String, ConsumerGroupTopicConf> set : entrySet) {
+                        if (!StringUtils.equals(subTopic.getTopic(), set.getKey())) {
+                            continue;
                         }
+
+                        ConsumerGroupTopicConf latestTopicConf = new ConsumerGroupTopicConf();
+                        latestTopicConf.setConsumerGroup(consumerGroup);
+                        latestTopicConf.setTopic(subTopic.getTopic());
+                        latestTopicConf.setSubscriptionItem(subTopic);
+                        latestTopicConf.setUrls(new HashSet<>(Arrays.asList(url)));
+
+                        ConsumerGroupTopicConf currentTopicConf = set.getValue();
+                        latestTopicConf.getUrls().addAll(currentTopicConf.getUrls());
+                        latestTopicConf.setIdcUrls(idcUrls);
+
+                        map.put(set.getKey(), latestTopicConf);
                     }
                 }
                 eventMeshHTTPServer.localConsumerGroupMapping.put(consumerGroup, consumerGroupConf);
