@@ -20,6 +20,7 @@ package org.apache.eventmesh.runtime.core.protocol.tcp.client.session.send;
 import org.apache.eventmesh.api.RequestReplyCallback;
 import org.apache.eventmesh.api.SendCallback;
 import org.apache.eventmesh.common.Constants;
+import org.apache.eventmesh.common.protocol.ProtocolTransportObject;
 import org.apache.eventmesh.common.protocol.tcp.Command;
 import org.apache.eventmesh.common.protocol.tcp.Header;
 import org.apache.eventmesh.common.protocol.tcp.OPStatus;
@@ -53,7 +54,7 @@ public class SessionSender {
     private final Logger messageLogger = LoggerFactory.getLogger("message");
     private final Logger logger = LoggerFactory.getLogger(SessionSender.class);
 
-    private Session session;
+    private final Session session;
 
     public long createTime = System.currentTimeMillis();
 
@@ -78,7 +79,7 @@ public class SessionSender {
         return upstreamBuff;
     }
 
-    private Semaphore upstreamBuff;
+    private final Semaphore upstreamBuff;
 
     public SessionSender(Session session) {
         this.session = session;
@@ -89,7 +90,7 @@ public class SessionSender {
         try {
             if (upstreamBuff.tryAcquire(TRY_PERMIT_TIME_OUT, TimeUnit.MILLISECONDS)) {
                 upMsgs.incrementAndGet();
-                UpStreamMsgContext upStreamMsgContext = null;
+                UpStreamMsgContext upStreamMsgContext;
                 Command cmd = header.getCmd();
 
                 String protocolVersion = header.getProperty(Constants.PROTOCOL_VERSION).toString();
@@ -105,7 +106,7 @@ public class SessionSender {
                     Span span = TraceUtils.prepareClientSpan(EventMeshUtil.getCloudEventExtensionMap(protocolVersion, event),
                         EventMeshTraceConstants.TRACE_UPSTREAM_EVENTMESH_CLIENT_SPAN, false);
                     try {
-                        session.getClientGroupWrapper().get()
+                        Objects.requireNonNull(session.getClientGroupWrapper().get())
                             .request(upStreamMsgContext, initSyncRRCallback(header,
                                 startTime, taskExecuteTime, event), ttl);
                         upstreamBuff.release();
@@ -121,7 +122,7 @@ public class SessionSender {
                     }
 
                     upStreamMsgContext = new UpStreamMsgContext(session, event, header, startTime, taskExecuteTime);
-                    session.getClientGroupWrapper().get().reply(upStreamMsgContext);
+                    Objects.requireNonNull(session.getClientGroupWrapper().get()).reply(upStreamMsgContext);
                     upstreamBuff.release();
                 } else {
                     upStreamMsgContext = new UpStreamMsgContext(session, event, header, startTime, taskExecuteTime);
@@ -129,14 +130,18 @@ public class SessionSender {
                     Span span = TraceUtils.prepareClientSpan(EventMeshUtil.getCloudEventExtensionMap(protocolVersion, event),
                         EventMeshTraceConstants.TRACE_UPSTREAM_EVENTMESH_CLIENT_SPAN, false);
                     try {
-                        session.getClientGroupWrapper().get()
+                        Objects.requireNonNull(session.getClientGroupWrapper().get())
                             .send(upStreamMsgContext, sendCallback);
                     } finally {
                         TraceUtils.finishSpan(span, event);
                     }
                 }
 
-                session.getClientGroupWrapper().get().getEventMeshTcpMonitor().getTcpSummaryMetrics().getEventMesh2mqMsgNum().incrementAndGet();
+                Objects.requireNonNull(session.getClientGroupWrapper().get())
+                    .getEventMeshTcpMonitor()
+                    .getTcpSummaryMetrics()
+                    .getEventMesh2mqMsgNum()
+                    .incrementAndGet();
             } else {
                 logger.warn("send too fast,session flow control,session:{}", session.getClient());
                 return new EventMeshTcpSendResult(header.getSeq(), EventMeshTcpSendStatus.SEND_TOO_FAST, EventMeshTcpSendStatus.SEND_TOO_FAST.name());
@@ -162,7 +167,8 @@ public class SessionSender {
                     .withExtension(EventMeshConstants.RSP_MQ2EVENTMESH_TIMESTAMP, String.valueOf(System.currentTimeMillis()))
                     .withExtension(EventMeshConstants.RSP_RECEIVE_EVENTMESH_IP, session.getEventMeshTCPConfiguration().eventMeshServerIp)
                     .build();
-                session.getClientGroupWrapper().get().getEventMeshTcpMonitor().getTcpSummaryMetrics().getMq2eventMeshMsgNum().incrementAndGet();
+                Objects.requireNonNull(session.getClientGroupWrapper().get()).getEventMeshTcpMonitor().getTcpSummaryMetrics().getMq2eventMeshMsgNum()
+                    .incrementAndGet();
 
                 Command cmd;
                 if (header.getCmd().equals(Command.REQUEST_TO_SERVER)) {
@@ -176,7 +182,7 @@ public class SessionSender {
                     .build();
                 String protocolType = Objects.requireNonNull(event.getExtension(Constants.PROTOCOL_TYPE)).toString();
 
-                ProtocolAdaptor protocolAdaptor = ProtocolPluginFactory.getProtocolAdaptor(protocolType);
+                ProtocolAdaptor<ProtocolTransportObject> protocolAdaptor = ProtocolPluginFactory.getProtocolAdaptor(protocolType);
 
                 Package pkg = new Package();
 
