@@ -33,6 +33,8 @@ import org.apache.eventmesh.runtime.util.Utils;
 import org.apache.commons.lang3.StringUtils;
 import org.apache.commons.lang3.time.DateFormatUtils;
 
+import java.util.Objects;
+
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -76,17 +78,17 @@ public class UpStreamMsgContext extends RetryContext {
     @Override
     public String toString() {
         return "UpStreamMsgContext{seq=" + seq
-                + ",topic=" + event.getSubject()
-                + ",client=" + session.getClient()
-                + ",retryTimes=" + retryTimes
-                + ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT) + "}"
-                + ",executeTime=" + DateFormatUtils.format(executeTime, EventMeshConstants.DATE_FORMAT);
+            + ",topic=" + event.getSubject()
+            + ",client=" + session.getClient()
+            + ",retryTimes=" + retryTimes
+            + ",createTime=" + DateFormatUtils.format(createTime, EventMeshConstants.DATE_FORMAT) + "}"
+            + ",executeTime=" + DateFormatUtils.format(executeTime, EventMeshConstants.DATE_FORMAT);
     }
 
     @Override
     public void retry() {
         logger.info("retry upStream msg start,seq:{},retryTimes:{},bizSeq:{}", this.seq, this.retryTimes,
-                EventMeshUtil.getMessageBizSeq(this.event));
+            EventMeshUtil.getMessageBizSeq(this.event));
 
         try {
             Command replyCmd = getReplyCmd(header.getCmd());
@@ -120,9 +122,9 @@ public class UpStreamMsgContext extends RetryContext {
             public void onSuccess(SendResult sendResult) {
                 session.getSender().getUpstreamBuff().release();
                 logger.info("upstreamMsg message success|user={}|callback cost={}", session.getClient(),
-                        System.currentTimeMillis() - createTime);
+                    System.currentTimeMillis() - createTime);
                 if (replyCmd.equals(Command.BROADCAST_MESSAGE_TO_SERVER_ACK) || replyCmd.equals(Command
-                        .ASYNC_MESSAGE_TO_SERVER_ACK)) {
+                    .ASYNC_MESSAGE_TO_SERVER_ACK)) {
                     msg.setHeader(new Header(replyCmd, OPStatus.SUCCESS.getCode(), OPStatus.SUCCESS.getDesc(), seq));
                     msg.setBody(event);
                     Utils.writeAndFlush(msg, startTime, taskExecuteTime, session.getContext(), session);
@@ -136,11 +138,11 @@ public class UpStreamMsgContext extends RetryContext {
                 // retry
                 // reset delay time
                 retryContext.delay(10000);
-                session.getClientGroupWrapper().get().getEventMeshTcpRetryer().pushRetry(retryContext);
+                Objects.requireNonNull(session.getClientGroupWrapper().get()).getEventMeshTcpRetryer().pushRetry(retryContext);
 
                 session.getSender().failMsgCount.incrementAndGet();
                 logger.error("upstreamMsg mq message error|user={}|callback cost={}, errMsg={}", session.getClient(),
-                        System.currentTimeMillis() - createTime, new Exception(context.getException()));
+                    System.currentTimeMillis() - createTime, new Exception(context.getException()));
                 msg.setHeader(new Header(replyCmd, OPStatus.FAIL.getCode(), context.getException().toString(), seq));
                 msg.setBody(event);
                 Utils.writeAndFlush(msg, startTime, taskExecuteTime, session.getContext(), session);
