@@ -36,6 +36,7 @@ import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Optional;
 
 import org.slf4j.Logger;
@@ -64,7 +65,7 @@ public class EventMeshClientUtil {
             .setUsername(clientConfig.getUserName())
             .setPassword(clientConfig.getPassword())
             .setProtocolType(protocolType)
-            .setProtocolDesc("grpc")
+            .setProtocolDesc(Constants.PROTOCOL_GRPC)
             // default CloudEvents version is V1
             .setProtocolVersion(SpecVersion.V1.toString())
             .build();
@@ -86,7 +87,7 @@ public class EventMeshClientUtil {
         if (EventMeshCommon.CLOUD_EVENTS_PROTOCOL_NAME.equals(protocolType)) {
             String contentType = message.getPropertiesOrDefault(ProtocolKey.CONTENT_TYPE, JsonFormat.CONTENT_TYPE);
             try {
-                CloudEvent cloudEvent = EventFormatProvider.getInstance().resolveFormat(contentType)
+                CloudEvent cloudEvent = Objects.requireNonNull(EventFormatProvider.getInstance().resolveFormat(contentType))
                     .deserialize(content.getBytes(StandardCharsets.UTF_8));
 
                 CloudEventBuilder cloudEventBuilder = CloudEventBuilder.from(cloudEvent)
@@ -117,19 +118,19 @@ public class EventMeshClientUtil {
                                                        String protocolType) {
         if (EventMeshCommon.CLOUD_EVENTS_PROTOCOL_NAME.equals(protocolType)) {
             CloudEvent cloudEvent = (CloudEvent) message;
-            String contentType = StringUtils.isEmpty(cloudEvent.getDataContentType()) ? "application/cloudevents+json"
+            String contentType = StringUtils.isEmpty(cloudEvent.getDataContentType()) ? Constants.CONTENT_TYPE_CLOUDEVENTS_JSON
                 : cloudEvent.getDataContentType();
-            byte[] bodyByte = EventFormatProvider.getInstance().resolveFormat(contentType)
+            byte[] bodyByte = Objects.requireNonNull(EventFormatProvider.getInstance().resolveFormat(contentType))
                 .serialize(cloudEvent);
             String content = new String(bodyByte, StandardCharsets.UTF_8);
             String ttl = cloudEvent.getExtension(Constants.EVENTMESH_MESSAGE_CONST_TTL) == null ? Constants.DEFAULT_EVENTMESH_MESSAGE_TTL
-                : cloudEvent.getExtension(Constants.EVENTMESH_MESSAGE_CONST_TTL).toString();
+                : Objects.requireNonNull(cloudEvent.getExtension(Constants.EVENTMESH_MESSAGE_CONST_TTL)).toString();
 
             String seqNum = cloudEvent.getExtension(ProtocolKey.SEQ_NUM) == null ? RandomStringUtils.generateNum(30)
-                : cloudEvent.getExtension(ProtocolKey.SEQ_NUM).toString();
+                : Objects.requireNonNull(cloudEvent.getExtension(ProtocolKey.SEQ_NUM)).toString();
 
             String uniqueId = cloudEvent.getExtension(ProtocolKey.UNIQUE_ID) == null ? RandomStringUtils.generateNum(30)
-                : cloudEvent.getExtension(ProtocolKey.UNIQUE_ID).toString();
+                : Objects.requireNonNull(cloudEvent.getExtension(ProtocolKey.UNIQUE_ID)).toString();
 
             SimpleMessage.Builder builder = SimpleMessage.newBuilder()
                 .setHeader(EventMeshClientUtil.buildHeader(clientConfig, protocolType))
@@ -142,7 +143,7 @@ public class EventMeshClientUtil {
                 .putProperties(ProtocolKey.CONTENT_TYPE, contentType);
 
             for (String extName : cloudEvent.getExtensionNames()) {
-                builder.putProperties(extName, cloudEvent.getExtension(extName).toString());
+                builder.putProperties(extName, Objects.requireNonNull(cloudEvent.getExtension(extName)).toString());
             }
 
             return builder.build();
@@ -183,20 +184,20 @@ public class EventMeshClientUtil {
                 .setTopic(events.get(0).getSubject());
 
             for (CloudEvent event : events) {
-                String contentType = StringUtils.isEmpty(event.getDataContentType()) ? "application/cloudevents+json"
+                String contentType = StringUtils.isEmpty(event.getDataContentType()) ? Constants.CONTENT_TYPE_CLOUDEVENTS_JSON
                     : event.getDataContentType();
-                byte[] bodyByte = EventFormatProvider.getInstance().resolveFormat(contentType)
+                byte[] bodyByte = Objects.requireNonNull(EventFormatProvider.getInstance().resolveFormat(contentType))
                     .serialize(event);
                 String content = new String(bodyByte, StandardCharsets.UTF_8);
 
                 String ttl = event.getExtension(Constants.EVENTMESH_MESSAGE_CONST_TTL) == null ? Constants.DEFAULT_EVENTMESH_MESSAGE_TTL
-                    : event.getExtension(Constants.EVENTMESH_MESSAGE_CONST_TTL).toString();
+                    : Objects.requireNonNull(event.getExtension(Constants.EVENTMESH_MESSAGE_CONST_TTL)).toString();
 
                 BatchMessage.MessageItem messageItem = BatchMessage.MessageItem.newBuilder()
                     .setContent(content)
                     .setTtl(ttl)
-                    .setSeqNum(event.getExtension(ProtocolKey.SEQ_NUM).toString())
-                    .setUniqueId(event.getExtension(ProtocolKey.UNIQUE_ID).toString())
+                    .setSeqNum(Objects.requireNonNull(event.getExtension(ProtocolKey.SEQ_NUM)).toString())
+                    .setUniqueId(Objects.requireNonNull(event.getExtension(ProtocolKey.UNIQUE_ID)).toString())
                     .putProperties(ProtocolKey.CONTENT_TYPE, contentType)
                     .build();
 
@@ -224,4 +225,4 @@ public class EventMeshClientUtil {
             return messageBuilder.build();
         }
     }
-}
+}
\ No newline at end of file
